PageEntity<T> class abstract

Implementers

Constructors

PageEntity({String? id, num? total, num? size, num? current, bool? optimizeCountSql, bool? searchCount, dynamic countId, num? maxLimit, num? pages})
PageEntity.fromJson(dynamic json)

Properties

countId ↔ dynamic
getter/setter pair
current num?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
maxLimit num?
getter/setter pair
optimizeCountSql bool?
getter/setter pair
pages num?
getter/setter pair
records List<T>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchCount bool?
getter/setter pair
size num?
getter/setter pair
total num?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toObject(dynamic json) → T
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited