RoleEntity class

Constructors

RoleEntity({String? id, String? createTime, String? appId, String? roleName, String? roleKey, String? parentId, int? sortNum, String? remark, int? uniqueFlag, int? enableFlag, String? tenantId})
RoleEntity.fromJson(dynamic json)

Properties

appId String?
getter/setter pair
children List<RoleEntity>?
getter/setter pair
createTime String?
getter/setter pair
enableFlag int?
getter/setter pair
expandFieldAndValues List<ExpandedField>?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
id String?
getter/setter pair
parentId String?
getter/setter pair
remark String?
getter/setter pair
roleKey String?
getter/setter pair
roleName String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortNum int?
getter/setter pair
tenantId String?
getter/setter pair
uniqueFlag int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override