UserPage class

Inheritance

Constructors

UserPage.fromJson(dynamic json)

Properties

countId ↔ dynamic
getter/setter pairinherited
current num?
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pairinherited
maxLimit num?
getter/setter pairinherited
optimizeCountSql bool?
getter/setter pairinherited
pages num?
getter/setter pairinherited
records List<User>?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchCount bool?
getter/setter pairinherited
size num?
getter/setter pairinherited
total num?
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
inherited
toObject(dynamic json) User
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited