EcpGlobalDebugUtils class
EcpGlobalDebugUtils类提供了调试时填充用户信息的工具方法 该类不能被实例化,只能通过类静态方法调用
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fillUserInfo(
) → dynamic - 填充用户信息 该方法用于在调试时异步加载和设置当前用户的详细信息 它首先检查当前用户的主要部门,然后从EcpGlobalApi获取用户的所有信息,并更新运行时环境