EcpDecodeUtils class

EcpDecodeUtils类提供了一组静态方法用于解码特定格式的字符串值。 这个类不能被实例化,只能通过类名访问其静态方法。

主要功能包括:

  • 解码给定的字符串值,基于当前用户ID进行数值运算以还原原始信息。

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(String? value) String?
解码给定的字符串值。