G class

global

Constructors

G()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

导航器的全局键
final

Static Methods

getCurrentContext() BuildContext?
获取当前的context
getCurrentState() NavigatorState?
获取当前的state
screenHeight() double
获取屏幕高度
screenPadding() EdgeInsets
获取屏幕上下边距
screenWidth() double
获取屏幕宽度