CandidateEntity class
Constructors
-
CandidateEntity({String? id, String? parentId, num? weight, String? name, num? isDept, List<
CandidateEntity> ? children, String? userId, String? roleKey}) - CandidateEntity.fromJson(dynamic json)
Properties
-
children
↔ List<
CandidateEntity> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String?
-
getter/setter pair
- isDept ↔ num?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- parentId ↔ String?
-
getter/setter pair
- roleKey ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId ↔ String?
-
getter/setter pair
- weight ↔ num?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override