EcpGlobalPath class
@author lzj
@since 2022/7/15 15:27
翼协云公共接口地址
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- getCandidate → const String
- getCurrentInterfaces → const String
- 登录后获取接口权限
- getDeptAndCompany → const String
- 根据部门ID获取部门和公司信息
- getDeptList → const String
- 获取所有部门列表
- getDeptTree → const String
- 获取部门层级树
- getDeptTreeByType → const String
- 通过类型获取部门层级树
- getGroupDicListTree → const String
- 获取数据字典列表
- getPartDeptTree → const String
- 获取部门层级树新接口
- getRolesBindUsersAndAllPermissions → const String
- 按角色获取用户列表
- getUserByRoleType → const String
- 按角色获取用户列表
- getUsers → const String
- 查询用户列表
- loginSimple → const String
- 用户名密码登录
- roleList → const String
- 角色列表
- searchUsersByPinyin → const String
- 模糊查询
- sysBusinessGroup → const String
- sysBusinessGroupItem → const String
- uploadFile → const String
- 单文件上传
- uploadFiles → const String
- 文件批量上传
- userAllInfoSelf → const String
- 获取用户所有信息