GlobalEventBus class
GlobalEventBus类用于提供一个全局的事件总线实例 事件总线是一种用于发布/订阅事件的软件架构模式,允许在组件之间松散耦合地进行通信 本类通过单例模式确保在整个应用中只有一个事件总线实例被创建和使用
Constructors
- GlobalEventBus()
-
factory
Properties
- event → EventBus
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited