RuntimeUtils class
运行时工具类,提供在运行时访问和设置当前用户和部门的方法
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- currentDepartment → Department?
-
获取当前部门
no setter
- currentUser → User?
-
获取当前用户
no setter
Static Methods
-
getRuntimeDepartment(
) → Department? - 获取运行时部门
-
getRuntimeEntity(
) → User? - 获取运行时实体用户
-
setRuntimeDepartment(
Department department) → dynamic - 设置运行时部门
-
setRuntimeEntity(
User re) → dynamic - 设置运行时实体用户